@@ -54,7 +54,7 @@ class MockTest < Test::Unit::TestCase
     mock = Mock.new
     OBJECT_METHODS.each { |method| mock.__expects__(method.to_sym).returns(method) }
     OBJECT_METHODS.each { |method| assert_equal method, mock.__send__(method.to_sym) }
-    assert mock.verified?
+    assert mock.__verified__?
   end
   
   def test_should_be_able_to_stub_standard_object_methods
@@ -113,30 +113,18 @@ class MockTest < Test::Unit::TestCase
     error = assert_raise(ExpectationError) do
       mock.unexpected_method_called(:my_method, :argument1, :argument2)
     end
+    assert_match(/unexpected invocation/, error.message)
     assert_match(/my_method/, error.message)
     assert_match(/argument1/, error.message)
     assert_match(/argument2/, error.message)
   end
   
-  def test_should_indicate_unexpected_method_called
-    mock = Mock.new
-    class << mock
-      attr_accessor :symbol, :arguments
-      def unexpected_method_called(symbol, *arguments)
-        self.symbol, self.arguments = symbol, arguments
-      end
-    end
-    mock.my_method(:argument1, :argument2)
-    assert_equal :my_method, mock.symbol
-    assert_equal [:argument1, :argument2], mock.arguments
-  end
-  
   def test_should_not_verify_successfully_because_not_all_expectations_have_been_satisfied
     mock = Mock.new
     mock.expects(:method1)
     mock.expects(:method2)
     mock.method1
-    assert !mock.verified?
+    assert !mock.__verified__?
   end
   
   def test_should_increment_assertion_counter_for_every_verified_expectation
@@ -150,7 +138,7 @@ class MockTest < Test::Unit::TestCase
     
     assertion_counter = SimpleCounter.new
     
-    mock.verified?(assertion_counter)
+    mock.__verified__?(assertion_counter)
     
     assert_equal 2, assertion_counter.count
   end
@@ -299,4 +287,16 @@ class MockTest < Test::Unit::TestCase
     end
   end
   
+  def test_should_handle_respond_to_with_private_methods_param_without_error
+    mock = Mock.new
+    assert_nothing_raised{ mock.respond_to?(:object_id, false) }
+  end
+  
+  def test_should_respond_to_any_method_if_stubbing_everything
+    mock = Mock.new
+    mock.stub_everything
+    assert mock.respond_to?(:abc)
+    assert mock.respond_to?(:xyz)
+  end
+  
 end
\ No newline at end of file
