@@ -8,7 +8,8 @@ module Stub
       @matches = matches
     end
 
-    def ==(value)
+    def matches?(available_parameters)
+      value = available_parameters.shift
       @value = value
       @matches
     end
@@ -16,6 +17,10 @@ module Stub
     def mocha_inspect
       "matcher(#{@matches})"
     end
+    
+    def to_matcher
+      self
+    end
 
   end
   
